.. FConcrete documentation master file, created by
   sphinx-quickstart on Tue Jan 28 20:04:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   https://pt.slideshare.net/shimizukawa/sphinx-autodoc-automated-api-documentation-pyconmy-2015
   https://books.google.com.br/books?id=VW3WDQAAQBAJ&pg=PA1079&lpg=PA1079&dq=sphinx+api+doc+in+deep&source=bl&ots=qOLaRPE82U&sig=ACfU3U28sF73mwtvuDhenI954jqCZpQu5Q&hl=pt-BR&sa=X&ved=2ahUKEwih7ofK26jnAhVIIbkGHVskBrQQ6AEwDXoECAoQAQ#v=onepage&q=sphinx%20api%20doc%20in%20deep&f=false

Welcome to FConcrete's documentation!
=====================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 1
   :caption: General Information:

   installation
   usage
   Module Structure <modules.rst>
   contributing
   authors
   history

.. toctree::
   :maxdepth: 3
   :caption: The module:
   
   Structural <fconcrete.Structural.rst>
   StructuralConcrete <fconcrete.StructuralConcrete.rst>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
